# Chrome Profile Extractor

##### version : 
    1.0.1

#####  Package
    pip install chrome-profile-extractor

##### package link :
    https://pypi.org/project/chrome-profile-extractor/

##### github link :
    https://github.com/HanZawNyein/chrome-profile-extractor.git

##### Author :
    Han Zaw Nyein

##### Author Email :
    hanzawnyineonline@gmail.com

### Description :
    this package for education purpose only.

### Example :
    from chrome_profile_extractor import extract_password, extract_cookie

    if __name__ == '__main__':
        print(extract_password)
        print(extract_cookie)
